/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.shape;

import java.awt.BorderLayout;
import java.awt.Color;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JToolBar;
import nl.cloudfarming.client.shape.preview.PreviewPanelPalette;
import nl.cloudfarming.client.shape.preview.ShapesPanel;
import org.netbeans.api.visual.action.ActionFactory;
import org.netbeans.api.visual.model.ObjectScene;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

@MultiViewElement.Registration(displayName = "#LBL_Shape_VISUAL",
iconBase = "nl/cloudfarming/client/shape/file_extension_shp.png",
mimeType = ShapeDataObject.MIMETYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "ShapeVisual",
position = 2000)
@Messages("LBL_Shape_VISUAL=Visual")
public final class ShapeVisualElement extends JPanel implements MultiViewElement {

    private ShapeDataObject obj;
    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;


    public ShapeVisualElement(Lookup lkp) {

        obj = lkp.lookup(ShapeDataObject.class);
        assert obj != null;
        initComponents();

    }

    @Override
    public String getName() {
        return "ShapeVisualElement";
    }

    /**
     */
    private void initComponents() {
        this.setLayout(new BorderLayout());
        ObjectScene scene = new ObjectScene();
        scene.getActions().addAction(ActionFactory.createZoomAction());
        scene.getActions().addAction(ActionFactory.createPanAction());        
        

        this.add(new ShapesPanel(obj, scene, new PreviewPanelPalette(Color.red)));
    }
    

    @Override
    public JComponent getVisualRepresentation() {
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return obj.getLookup();
    }

    @Override
    public void componentOpened() {
    }

    @Override
    public void componentClosed() {
    }

    @Override
    public void componentShowing() {
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
        callback.updateTitle(obj.getName());
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }
}
