/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.shape.preview;

import java.awt.Color;
import java.awt.event.ItemListener;
import java.util.List;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import net.miginfocom.swing.MigLayout;
import org.openide.util.NbBundle;

/**
 * Allows the user to select the property from a shapefile which represents the
 * 'Name' of a shape
 *
 * @author Gerben Feenstra
 */
@NbBundle.Messages({
    "Shape property mapping panel name label=Name: ",
    "Shape property mapping panel no properties message= None found"
})
public class ShapePropertyMappingPanel extends JPanel {

    public static final String PROP_COMBOBOX_NAME = "nameBox";
    public static final String PROP_COMBOBOX_TYPE = "typeBox";
    private DefaultComboBoxModel shapePropertiesModel = new DefaultComboBoxModel();
    private JComboBox propertiesBox;

    public ShapePropertyMappingPanel() {
        this.setLayout(new MigLayout("wrap 2"));
        this.setBackground(Color.white);
        propertiesBox = new JComboBox(shapePropertiesModel);
        propertiesBox.setName(PROP_COMBOBOX_NAME);
        this.add(new JLabel(Bundle.Shape_property_mapping_panel_name_label()), "gaptop 20");
        this.add(propertiesBox, "gaptop 20");
    }

    /**
     * Set available shape properties
     *
     * @param properties
     */
    public void setAvailableProperties(List<String> properties) {
        shapePropertiesModel.removeAllElements();
        if (properties == null || properties.isEmpty()) {
            shapePropertiesModel.addElement(Bundle.Shape_property_mapping_panel_no_properties_message());
            propertiesBox.setEnabled(false);
        } else {
            propertiesBox.setEnabled(true);
            for (String property : properties) {
                shapePropertiesModel.addElement(property);
            }
            if (shapePropertiesModel.getIndexOf("") >= 0) {
                shapePropertiesModel.setSelectedItem("");
            }
        }

    }

    /**
     * Get the selected shape property
     *
     * @return
     */
    public String getSelectedNameProperty() {
        return (String) shapePropertiesModel.getSelectedItem();
    }

    public void addItemListener(ItemListener listener) {
        propertiesBox.addItemListener(listener);
    }

    public void removeItemListener(ItemListener listener) {
        propertiesBox.removeItemListener(listener);
    }
}
